import os
import sys
import typing
from contextlib import contextmanager


def add_path(path: str) -> None:
    """ Add specified path to the environment PATH variable

    :param path: path to add to PATH
    """
    os.environ['PATH'] = path + os.pathsep + os.environ['PATH']


@contextmanager
def supress_stdout(dest_path: str = os.devnull) -> typing.Generator[None, None, None]:
    stdout_fileno = sys.stdout.fileno()

    def _redirect_stdout(dest: typing.IO) -> None:
        # Close original handle
        sys.stdout.close()

        # Duplicate handle
        os.dup2(dest.fileno(), stdout_fileno)

        sys.stdout = os.fdopen(stdout_fileno, 'w')

    with os.fdopen(os.dup(stdout_fileno), 'w') as stdout_file:
        try:
            with open(dest_path, 'w') as dest_file:
                _redirect_stdout(dest_file)

            yield
        finally:
            # Restore original stdout
            _redirect_stdout(stdout_file)



#!/usr/bin/env python

import os
import re

from setuptools import setup, find_packages


# Read properties from __init__.py
with open(os.path.join(os.path.dirname(__file__), 'pylinkam', '__init__.py')) as file_init:
    content_init = file_init.read()

    version = re.search("__version__ = '([^']+)'", content_init).group(1)

    author = re.search("__author__ = '([^']+)'", content_init).group(1)

    maintainer = re.search("__maintainer__ = '([^']+)'", content_init).group(1)
    maintainer_email = re.search("__email__ = '([^']+)'", content_init).group(1)


setup(
    name='pylinkam',
    version=version,
    description='Python bindings for the official Linkam SDK',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author=author,
    maintainer=maintainer,
    maintainer_email=maintainer_email,
    packages=find_packages(),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Natural Language :: English',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Topic :: System :: Hardware',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    license='GPLv3',
    platforms='any'
)
